@@ -83,6 +83,9 @@ load_thumb_error_cb (ThumbLoader *tl,
 	GthFileList *file_list = data;
 	float        percent;
 
+	if (file_list == NULL)
+		return;
+
 	gth_file_view_set_unknown_pixbuf (file_list->view,  file_list->thumb_pos);
 
 	file_list->thumb_fd->error = TRUE;
@@ -105,6 +108,9 @@ load_thumb_done_cb (ThumbLoader *tl,
 	GthFileList *file_list = data;
 	float        percent;
 
+	if (file_list == NULL)
+		return;
+
 	update_thumb_in_clist (file_list);
 	file_list->thumb_fd->error = FALSE;
 	file_list->thumb_fd->thumb = TRUE;
@@ -136,6 +142,11 @@ gth_file_list_finalize (GObject *object)
 
         g_return_if_fail (GTH_IS_FILE_LIST (object));
 	file_list = GTH_FILE_LIST (object);
+	
+	if (file_list->thumb_fd != NULL) {
+		file_data_unref (file_list->thumb_fd);
+		file_list->thumb_fd = NULL;
+	}
 
 	gth_file_list_free_list (file_list);
 	g_object_unref (file_list->thumb_loader);
@@ -1408,13 +1419,6 @@ set_thumbs_size__step2 (InterruptThumbsData *it_data)
 
 	gth_file_view_set_image_width (file_list->view, size + THUMB_BORDER);
 
-	/* FIXME
-	if (it_data->restart_thumbs) {
-		file_list->doing_thumbs = TRUE;
-		gth_file_list_update_next_thumb (file_list);
-	}
-	*/
-
 	it_data_free (it_data);
 }
 
@@ -1511,8 +1515,9 @@ gth_file_list_update_thumb (GthFileList  *file_list,
 	fd->thumb = FALSE;
 
 	file_list->thumb_pos = pos;
+	if (file_list->thumb_fd != NULL)
+		file_data_unref (file_list->thumb_fd);
 	file_list->thumb_fd = fd;
-	file_data_unref (fd);
 
 	gth_file_list_update_current_thumb (file_list);
 }
@@ -1559,6 +1564,11 @@ gth_file_list_thumb_cleanup (GthFileList *file_list)
 	file_list->thumbs_num = 0;
 	file_list->doing_thumbs = FALSE;
 
+	if (file_list->thumb_fd != NULL) {
+		file_data_unref (file_list->thumb_fd);
+		file_list->thumb_fd = NULL;
+	}
+
 	if (file_list->progress_func) 
 		file_list->progress_func (0.0, file_list->progress_data);
 }
@@ -1613,7 +1623,11 @@ gth_file_list_update_next_thumb (GthFileList *file_list)
 
 	file_list->thumb_pos = new_pos;
 	file_list->thumbs_num++;
+
+	if (file_list->thumb_fd != NULL)
+		file_data_unref (file_list->thumb_fd);
 	file_list->thumb_fd = fd;
+	file_data_ref (file_list->thumb_fd);
 
 	gth_file_list_update_current_thumb (file_list);
 }
